//@line 36 "/builds/slave/2.1-mob-lnx-ntly/build/mozilla-2.1/mobile/locales/en-US/mobile-l10n.js"

//@line 38 "/builds/slave/2.1-mob-lnx-ntly/build/mozilla-2.1/mobile/locales/en-US/mobile-l10n.js"

pref("general.useragent.locale", "en-US");
